/*
COPYRIGHT NOTICE
Copyright (c) 2003  Scott C. Neu, Daniel J. Valentino, and Arthur W. Toga

See README.license for license notices.
 */

package edu.ucla.loni.debabel.processors.stdlib;

import edu.ucla.loni.moduleio.spi.ProcessorSpi;
import java.util.Locale;
import java.util.Vector;

/**
 * Processor SPI (Service Provider Interface) for Debabeler Standard Library.
 *
 * @version 24 June 2003
 */
public class StdLibraryProcessorSpi extends ProcessorSpi
{
  /** Name of the vendor who supplied this plug-in. */
  private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

  /** Version of this plug-in. */
  private static String _version = "1.3.1";

  /** Name of the library of Processors. */
  private static String _libraryName 
                          = "LONI Debabeler Standard Processor Library";

  /** Comment pertaining to the library. */
  private static String _libraryComment 
                          = "Authors: Neu, Ouellette, Created: 24 June 2003";

  /** Constructs a Standard Library Processor SPI. */
  public StdLibraryProcessorSpi()
    {
      super(_vendorName, _version, _libraryName, _libraryComment);
    }

  /**
   * Returns a brief, human-readable description of this service provider and
   * its associated implementation.
   *
   * @param locale Locale for which the return value should be localized.
   *
   * @return Description of this service provider.
   */
  public String getDescription(Locale locale)
    {
      return _libraryName;
    }

  /**
   * Gets an array of fully-qualified class names of the Processors belonging
   * to the library.
   *
   * @return Fully-qualified class names of the Processors belonging to the
   *         library.
   */
  public String[] getProcessorClassNames()
    {
      Vector names = new Vector();

      // Add the class names
      names.add( ArithmeticOperator.class.getName() );
      names.add( ArrayCaster.class.getName() );
      names.add( ArrayIndexer.class.getName() );
      names.add( ArrayMaker.class.getName() );
      names.add( ArraySizer.class.getName() );
      names.add( BooleanOperator.class.getName() );
      names.add( ClassDeterminer.class.getName() );
      names.add( CollectionsSearcher.class.getName() );
      names.add( Comparer.class.getName() );
      names.add( Constant.class.getName() );
      names.add( Defaulter.class.getName() );
      names.add( FixedArrayMaker.class.getName() );
      names.add( Identity.class.getName() );
      names.add( InstanceofOperator.class.getName() );
      names.add( ListManipulator.class.getName() );
      names.add( ModAndBitwiseOperator.class.getName() );
      names.add( MultiStringConcatenator.class.getName() );
      names.add( Not.class.getName() );
      names.add( ObjectCaster.class.getName() ); 
      names.add( PrimitiveDefaulter.class.getName() );
      names.add( PrimitiveTypeConverter.class.getName() );
      names.add( StringChecker.class.getName() );
      names.add( StringComparer.class.getName() );
      names.add( StringReplacer.class.getName() );
      names.add( StringUtilities.class.getName() );
      names.add( TernaryOperator.class.getName() ); 
      names.add( ToString.class.getName() );
      names.add( ValueHolder.class.getName() );
      
      // Convert the Vector to a String array
      String[] array = new String[ names.size() ];
      for (int i = 0; i < array.length; i++) {
	array[i] = (String)names.elementAt(i);
      }

      // Return the String array
      return array;
    }
}
